import type { InboundTransport } from '../transport';
import type { TransportSession } from './TransportService';
import { ConnectionService } from '../modules/connections/services/ConnectionService';
import { AgentConfig } from './AgentConfig';
import { Dispatcher } from './Dispatcher';
import { EnvelopeService } from './EnvelopeService';
import { TransportService } from './TransportService';
export declare class MessageReceiver {
    private config;
    private envelopeService;
    private transportService;
    private connectionService;
    private dispatcher;
    private logger;
    readonly inboundTransports: InboundTransport[];
    constructor(config: AgentConfig, envelopeService: EnvelopeService, transportService: TransportService, connectionService: ConnectionService, dispatcher: Dispatcher);
    registerInboundTransport(inboundTransport: InboundTransport): void;
    /**
     * Receive and handle an inbound DIDComm message. It will unpack the message, transform it
     * to it's corresponding message class and finally dispatch it to the dispatcher.
     *
     * @param inboundPackedMessage the message to receive and handle
     */
    receiveMessage(inboundPackedMessage: unknown, session?: TransportSession): Promise<void>;
    /**
     * Unpack a message using the envelope service.
     * If message is not packed, it will be returned as is, but in the unpacked message structure
     *
     * @param packedMessage the received, probably packed, message to unpack
     */
    private unpackMessage;
    private isUnpackedMessage;
    /**
     * Transform an unpacked DIDComm message into it's corresponding message class. Will look at all message types in the registered handlers.
     *
     * @param unpackedMessage the unpacked message for which to transform the message in to a class instance
     */
    private transformMessage;
}
